import React, { Fragment } from 'react'
import { Flex, Modal, Toast, Result, Tabs, ActivityIndicator, Icon, Calendar } from 'antd-mobile';
import router from 'umi/router'
import NativeHook from '@/utils/NativeHook'
import Url from '@/utils/Url'
import styles from './Detail.less'

class Detail extends React.Component {
  constructor(props) {
    super(props)
    this.coinId = Url.getQueryString
    this.state = {
      firstLoad: false,
      
    }
  }

  componentDidMount() {
    NativeHook.init()
    document.title = '明细'
    
  }

  componentWillUnmount() {
    NativeHook.destroy()
    if(this.timer) {
      clearTimeout(this.timer)
    }
  }

  


  render() {
    const { err, errMsg, firstLoad } = this.state
    if(firstLoad) {
      return <ActivityIndicator toast animating text="加载中" />
    } else return (
      <Fragment>
        {!err && (
          <div className={styles.wrapper}>
            <div className={styles.tabs}>
              <Tabs
                tabs={[{ title: '支出' }, { title: '收入' }]}
                swipeable={false}
              >
                <TabPane transType={2}/>
                <TabPane transType={1} />
              </Tabs>
            </div>
          </div>
        )}
        {err && (
          <Result
            img={<img style={{ width: '1.2rem', height: '1.2rem' }} src={require('@/assets/icon-err.png')} />}
            title="信息错误"
            message={errMsg}
          />
        )}
      </Fragment>
    )
  }
}

export default Detail


class TabPane extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      timeModal: false,
      list: [1,2,3,4,5,6,7,8,9,10,12,13,14],
      pagination: {
        pageSize: 20,
        pageIndex: 1,
        total: 0
      },
      coinId: Url.getQueryString('coinId'),
      coinName: Url.getQueryString('cN')
    }
  }

  componentDidMount() {
    this.getAccountHisList(this.state.pagination.pageIndex)   //获取账户记录列表
    this.listRef.addEventListener('scroll', this.bindScroll)
  }

  componentWillUnmount() {
    this.listRef.removeEventListener('scroll', this.bindScroll)
  }

  //获取账户记录列表
  getAccountHisList = (pageIndex) => {
    const { transType } = this.props
    const { coinId } = this.state
    const params = {
      pageIndex,
      transType,
      coinId
    }
    if (this.state.loading) return
    this.setState({ loading: true }, () => {
      NativeHook.call.getData({
        api: '/api-app/v1/chain/getAccountHisList',
        params,
        isDialogShow: false
      }, (res) => {
        if (res.success) {
          const { total, pageSize } = res.data
          let { hasNext, pagination, list } = this.state
          if (pageIndex > 1) {
            list = [...list, ...res.data.list]
          } else {
            list = res.data.list
          }
          if (pageIndex * pagination.pageSize < total) {
            hasNext = true
          } else {
            hasNext = false
          }
          pagination.pageIndex = pageIndex
          pagination.pageSize = pageSize
          this.setState({ loading: false, list, hasNext, pagination, firstLoad: false })
        } else {
          this.setState({ loading: false, firstLoad: false }, () => {
            Toast.fail(res.msg)
            console.log(res.msg)
          })
        }
      })
    })
  }

  pickTime = (start, end) => {
    console.log(start, end)
    this.setState({ timeModal: false })
  }

  bindScroll = (event) => {
    //console.log(this.listRef.scrollHeight, this.listRef.scrollTop, this.listRef.clientHeight)
    // 滚动的高度
    const scrollTop = this.listRef.scrollTop
    // 视窗高度
    const clientHeight = this.listRef.clientHeight
    // 页面高度
    const scrollHeight = this.listRef.scrollHeight
    // 距离页面底部的高度
    const height = scrollHeight - scrollTop - clientHeight;
    // 判断距离页面底部的高度 
    if (height <= 500) {
      console.log('触底')
      if (this.state.hasNext) {
        //this.getPropsList(this.state.pagination.pageIndex + 1)   //加载下一页
      }
    }
  }

  testLog() {
    console.log(this.listRef)
  }

  render() {
    const {list } = this.state
    return(
      <div className={styles.tabPane} ref={ref => this.listRef = ref }>
        <div className={styles['bar-money']}>
          <div className={styles.num} onClick={this.testLog.bind(this)}>232323</div>
          <div className={styles.name}>{this.state.coinName}</div>
        </div>
        {/* 列表 */}
        <Flex align="center" justify="between" className={styles['bar-time']}>
          <div>2019年12月 <Icon style={{ color: '#ccc', verticalAlign: 'middle' }} type="right"/></div>
          <img className={styles['icon-time']} src={require('@/assets/icon_time.png')} onClick={() => this.setState({timeModal: true}) }/>
        </Flex>
        {/* 日历 */}
        <Calendar
          visible={this.state.timeModal}
          onCancel={() => this.setState({ timeModal: false })}
          onConfirm={this.pickTime}
          getDateExtra={this.getDateExtra}
          defaultDate={new Date()}
        />
        { list.length > 0 ? (
          <Fragment>
            {list.map((item, i) => {
              return (
                <Flex align="center" justify="between" key={i} className={styles['list-item']}>
                  <div>
                    <div>赠送 <span style={{ color: '#FF4D5C' }}>温柔乡：兜兜</span> 1个比心</div>
                    <div className={styles.time}>2019-9-9 11:26:30</div>
                  </div>
                  <div className={styles.money}>-12</div>
                </Flex>
              )
            })}
          </Fragment>
        ) : (
          <div className={styles.noData}>暂无记录</div>
        ) }
      </div>
    )
  }
}