import React, { Fragment, useEffect } from 'react'
import { Flex, Modal, Toast, Result, ActivityIndicator, Icon } from 'antd-mobile';
import router from 'umi/router'
import NativeHook from '@/utils/NativeHook'
import styles from './Home.less'

class Home extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      list: [],
      firstLoading: true,
      walletItems: {},
      accountObj: {}
    }
  }

  componentDidMount() {
    NativeHook.init()
    document.title = '我的钱包'
    this.getVirtualCoinList()  //获取币种列表
    this.getUserVirtualWallet()
  }

  componentWillUnmount() {
    NativeHook.destroy()
    if(this.timer) {
      clearTimeout(this.timer)
    }
  }

  //钱包
  getUserVirtualWallet() {
    NativeHook.call.getData({
      api: '/api-app/v1/wallet/getUserVirtualWallet',
      params: {},
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        const list = res.data.walletItems
        const walletItems = {}
        for( let item of list ) {
          walletItems[item.walletType] = item.balance
        }
        this.setState({ walletItems })
      }
    })
  }

  getAccounts(list) {
    NativeHook.call.getData({
      api: '/api-app/v1/chain/getAccounts',
      params: {},
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        const accountObj = {}
        for( let item of res.data.list ) {
          accountObj[item.coinNet] = item.accountAddress
        }
        for( let item of list ) {
          if(accountObj[item.coinNet]) {
            item.accountAddress = accountObj[item.coinNet]
          }
        }
        this.setState({ list })
      }
    })
  }

   //获取币种列表
  getVirtualCoinList() {
    NativeHook.call.getData({
      api: '/api-app/v1/chain/getVirtualCoinList',
      params: {},
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        const list = res.data.list
        this.setState({ list }, ()=>{
          this.getAccounts(list)
          if (this.state.firstLoading) {
            this.timer = setTimeout(() => {
              this.setState({ firstLoading: false })
            }, 300);
          }
        })
      } else {
        this.setState({ err: true, errMsg: res.msg })
      }
    })
  }
  
  //查看明细
  goDetail(info) {
    console.log('查看明细: ', info.coinId )
    NativeHook.go.walletRecord({
      walletType: info.coinId
    }, ()=>{})
  }

  //转出
  getOut(info) {
    const { walletItems } = this.state
    info.balance = walletItems[info.coinId]
    window.sessionStorage.coinInfo = JSON.stringify(info)
    router.push('/transferOut')
  }

  // 充值
  goRecharge = info => e => {
    const { walletItems } = this.state
    info.balance = walletItems[info.coinId]
    window.sessionStorage.coinInfo = JSON.stringify(info)
    router.push('/recharge')
  }

  //创建账号
  buildAccount = (info) => {
    if(this.state.buildLoading) return
    Toast.loading('创建中', 0)
    this.setState({ buildLoading: true })
    NativeHook.call.postData({
      api: '/api-app/v1/chain/createAccount',
      params: {
        coinNet: info.coinNet
      },
      isDialogShow: false
    }, (res) => {
      Toast.hide()
      if (res.success) {
        Toast.success('账号创建成功', 1.5)
        const {list} = this.state
        for( let item of list ) {
          if(item.coinId === info.coinId ) {
            item.accountAddress = res.data
            break
          }
        }
        this.setState({ buildLoading: false, list })
      } else {
        Toast.info(res.msg, 1)
      }
    })
  }

  render() {
    const { err, errMsg, list, firstLoading, walletItems } = this.state
    if (firstLoading) {
      return <ActivityIndicator toast animating text="加载中" />
    } else return (
      <Fragment>
        {!err && (
          <div className={styles.wrapper}>
            {list.map((item, i) => {
              return (
                <Item
                  key={i}
                  item={item}
                  goDetail={this.goDetail.bind(this, item)}
                  getOut={this.getOut.bind(this, item)}
                  goRecharge={this.goRecharge(item)}
                  walletItems={walletItems}
                  buildAccount={this.buildAccount.bind(this, item)}
                />
              )
            })}
            { list.length === 0 && (
              <div style={{ paddingTop: '3rem' }}>
                <img style={{ width: '2.4rem', height: '2.4rem' }} src={require('@/assets/img_no.png')} />
                <div className="color-999">暂无记录</div>
              </div>
            ) }

          </div>
        )}
        {err && (
          <Result
            img={<img style={{ width: '1.2rem', height: '1.2rem' }} src={require('@/assets/icon-err.png')} />}
            title="信息错误"
            message={errMsg}
          />
        )}
      </Fragment>
    )
  }
}

export default Home

function Item(props) {


  const { item, walletItems } = props
  return(
    <Flex align="center" justify="between" className={styles['list-item']}>
      <img className={styles['wallet-img']} src={item.coinIcon} />
      <Flex direction="column" justify="between" align="start" style={{ width: '2.62rem' }}>
        <div className={styles.name}>{item.coinName}</div>
        <div className={styles.num} onClick={props.goDetail}>数量 {walletItems[item.coinId] || 0 } ></div>
      </Flex>
      { item.accountAddress && (
        <Fragment>
          <div className={styles.button} onClick={props.goRecharge}>充值</div>
          <div className={styles.button} onClick={props.getOut}>转出</div>
        </Fragment>
      ) }
      {!item.accountAddress && (
        <div className={styles.button} onClick={props.buildAccount}>创建账号</div>
      )}
    </Flex>
  )
}