import React, { Fragment } from 'react'
import { Flex, Modal, Toast, Result, Tabs, ActivityIndicator, Icon, Calendar } from 'antd-mobile';
import router from 'umi/router'
import NativeHook from '@/utils/NativeHook'
import Url from '@/utils/Url'
import styles from './Record.less'
import * as Format from '@/utils/Format'

class Record extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      firstLoading: false,
    }
  }

  componentDidMount() {
    document.title = Url.getQueryString('transType') === '2' ? '转出记录' : '充值记录'
  }

  render() {
    const { err, errMsg, firstLoading } = this.state
    if(firstLoading) {
      return <ActivityIndicator toast animating text="加载中" />
    } else return (
      <Fragment>
        {!err && (
          <div className={styles.wrapper}>
            <List />
          </div>
        )}
        {err && (
          <Result
            img={<img style={{ width: '1.2rem', height: '1.2rem' }} src={require('@/assets/icon-err.png')} />}
            title="信息错误"
            message={errMsg}
          />
        )}
      </Fragment>
    )
  }
}

export default Record


class List extends React.Component {
  constructor(props) {
    super(props)
    this.transType = Url.getQueryString('transType')
    this.state = {
      list: [],
      pagination: {
        pageSize: 20,
        pageIndex: 1,
        total: 0
      },
      firstLoading: false,
      coinInfo: {}
    }
  }

  componentDidMount() {
    NativeHook.init()
    const coinInfo = window.sessionStorage.coinInfo ? JSON.parse(window.sessionStorage.coinInfo) : {}
    this.setState({ coinInfo }, ()=>{
      this.getAccountHisList(this.state.pagination.pageIndex)   //获取账户记录列表
    })
    this.listRef.addEventListener('scroll', this.bindScroll)
  }

  componentWillUnmount() {
    this.listRef.removeEventListener('scroll', this.bindScroll)
    NativeHook.destroy()
    if (this.timer) {
      clearTimeout(this.timer)
    }
  }

  //获取账户记录列表
  getAccountHisList = (pageIndex) => {
    const { coinInfo } = this.state
    const params = {
      pageIndex,
      transType: this.transType,
      coinId: coinInfo.coinId
    }
    if (this.state.loading) return
    this.setState({ loading: true }, () => {
      NativeHook.call.getData({
        api: '/api-app/v1/chain/getAccountHisList',
        params,
        isDialogShow: false
      }, (res) => {
        if (res.success) {
          const { total, pageSize } = res.data
          let { hasNext, pagination, list } = this.state
          if (pageIndex > 1) {
            list = [...list, ...res.data.list]
          } else {
            list = res.data.list
          }
          if (pageIndex * pagination.pageSize < total) {
            hasNext = true
          } else {
            hasNext = false
          }
          pagination.pageIndex = pageIndex
          pagination.pageSize = pageSize
          this.setState({ loading: false, list, hasNext, pagination }, ()=>{
            if(this.state.firstLoading) {
              this.timer = setTimeout(() => {
                this.setState({ firstLoading: false })
              }, 500);
            }
          })
        } else {
          this.setState({ loading: false, firstLoading: false }, () => {
            Toast.fail(res.msg)
            console.log(res.msg)
          })
        }
      })
    })
  }

  bindScroll = (event) => {
    //console.log(this.listRef.scrollHeight, this.listRef.scrollTop, this.listRef.clientHeight)
    // 滚动的高度
    const scrollTop = this.listRef.scrollTop
    // 视窗高度
    const clientHeight = this.listRef.clientHeight
    // 页面高度
    const scrollHeight = this.listRef.scrollHeight
    // 距离页面底部的高度
    const height = scrollHeight - scrollTop - clientHeight;
    // 判断距离页面底部的高度 
    if (height <= 500) {
      console.log('触底')
      if (this.state.hasNext) {
        this.getAccountHisList(this.state.pagination.pageIndex + 1)   //加载下一页
      }
    }
  }

  testLog() {
    console.log(this.listRef)
  }

  render() {
    const { list, firstLoading, coinInfo } = this.state
    if (firstLoading) {
      return <ActivityIndicator toast animating text="加载中" />
    } else return (
      <div className={styles.tabPane} ref={ref => this.listRef = ref}>
        {list.length > 0 ? (
          <Fragment>
            {list.map((item, i) => {
              return (
                <Flex align="center" justify="between" key={i} className={styles['list-item']}>
                  <div style={{ width: '60%' }}>
                    <div className={styles.time}>{Format.date(item.hisCreateTime, 'yyyy-MM-dd HH:mm')}</div>
                    <div className={styles.address}>转出地址：{item.toAddress}</div>
                  </div>
                  <div className={styles.hisAmount} style={{ width: '40%', textAlign: 'right' }}>
                    <div>
                      <span>{this.transType === '2' ? '-' : '+'}</span>
                      <span>{item.hisAmount}</span>
                    </div>
                    <div className={styles.status}>
                      {item.hisStatus === 102 && <span style={{ color: '#FF4D5C' }}>处理失败</span>}
                      {item.hisStatus === 201 && <span style={{ color: '#29CC70' }}>处理成功</span>}
                      {item.hisStatus === 101 && <span style={{ color: '#3399FF' }}>处理中</span>}
                    </div>
                  </div>
                </Flex>
              )
            })}
          </Fragment>
        ) : (
            <div className={styles.noData}>
              <img style={{ width: '2.4rem', height: '2.4rem' }} src={require('@/assets/img_no.png')}/>
              <div>暂无记录</div>
            </div>
          )}
      </div>
    )
  }
}