import React, { Fragment } from 'react'
import { Flex, Modal, Toast, Result, Tabs, ActivityIndicator, Icon, InputItem } from 'antd-mobile';
import router from 'umi/router'
import NativeHook from '@/utils/NativeHook'
import styles from './TransferOut.less'

class TransferOut extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      coinInfo: {}
    }
  }

  componentDidMount() {
    NativeHook.init()
    document.title = '转出'
    const coinInfo = window.sessionStorage.coinInfo ? JSON.parse(window.sessionStorage.coinInfo) : {}
    this.setState({ coinInfo })
  }

  componentWillUnmount() {
    NativeHook.destroy()
    if(this.timer) {
      clearTimeout(this.timer)
    }
  }

  applyWithdraw = ()=>{
    const { amount, loading, coinInfo, toAddress } = this.state
    if (!amount || amount <= 0 || !amount.toString().match(/^[+-]?(0|([1-9]\d*))(\.\d+)?$/g)) {
      Toast.fail('请输入有效数量', 1)
      return
    }
    if (!toAddress) {
      Toast.fail('请输入钱包地址', 1)
      return
    }
    if (Number(amount) > Number(coinInfo.balance) ) {
      Toast.fail('余额不足', 1)
      return
    }
    if (loading) return
    this.setState({ loading: true })
    NativeHook.call.postData({
      api: '/api-app/v1/chain/applyWithdraw',
      params: {
        coinId: coinInfo.coinId,
        amount,
        toAddress: toAddress
      },
      isDialogShow: false
    }, (res) => {
      if (res.success) {
        Toast.success('转出成功', 1)
        coinInfo.balance = coinInfo.balance - amount
        window.sessionStorage.coinInfo = JSON.stringify(coinInfo)
        this.setState({ loading: false, amount: undefined, toAddress: undefined, coinInfo })
      } else {
        Toast.info(res.msg, 1.5)
        this.setState({ loading: false })
      }
    })
  }

  testLog() {
    console.log(this.state)
  }

  goRecord = ()=>{
    router.push('/record?transType=2')
  }


  render() {
    const { coinInfo, loading } = this.state
    if (coinInfo.coinInfo) {
      return <ActivityIndicator toast animating text="加载中" />
    } else return(
      <div className={styles.wrapper}>
        <div className={styles.item}>
          <div className={styles.title} onClick={this.testLog.bind(this)}>{coinInfo.coinName}</div>
          <div className="color-999 font-28">可用数量 {coinInfo.balance}</div>
        </div>
        <div className={styles.item}>
          <div className={styles.title}>钱包地址</div>
          <div className={styles.input}>
            <InputItem
              clear
              placeholder="请输入钱包地址"
              value={this.state.toAddress}
              onChange={toAddress => this.setState({ toAddress })}
            />
          </div>
        </div>
        <div className={styles.item}>
          <div className={styles.title}>转出数量</div>
          <div className={styles.input}>
            <InputItem
              clear
              type="number"
              placeholder="请输入转出数量"
              value={this.state.amount}
              onChange={amount => this.setState({ amount })}
            />
          </div>
        </div>
        <div className={styles.button} onClick={this.applyWithdraw}>{loading ? <Icon type="loading" style={{ verticalAlign: 'middle'}}/> : '申请转出'}</div>
        <div className="font-28 color-primary" style={{ textAlign: 'center' }} onClick={ this.goRecord }>转出记录</div>
      </div>
    )
  }
}

export default TransferOut

