import UAParser from 'ua-parser-js'
import { stringify } from 'qs';
import request from '@/utils/request';

const UA = new UAParser().getResult()
const callbacks = {}
const METHOD_LIST = ['getData', 'postData', 'close', 'go']
const PAGES = ['recharge', 'walletRecord']

function randomString(len) {
  len = len || 32;
  const chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
  let maxPos = chars.length;
  let pwd = '';
  for (let i = 0; i < len; i++) {
    pwd += chars.charAt(Math.floor(Math.random() * maxPos));
  }
  return pwd
}

const onNativeCallback = (key, result) => {
  if (result instanceof String) {
    result = JSON.parse(result)
  }
  const cb = callbacks[key]
  cb && cb(result)
  delete callbacks[key]
}

function isIOS() {
  return UA.os.name == 'iOS'
}

function isAndroid() {
  return UA.os.name == 'Android'
}

const getCallbackKey = (method) => {
  return method + '_' + new Date().getTime() + '_' + randomString(6)
}

const envokeNative = (method, args, cb) => {
  if (cb) {
    const key = getCallbackKey(method)
    callbacks[key] = cb
    args = args || {}       //调接口传参
    args._key = key         //调取成功以后APP调取该回调方法，识别的方法名
  }
  //非内置APPweb
  if (UA.browser.name === 'WeChat') {
    if (method === 'getData') {
      //console.log(method, args, cb)
      const fetchPromise = request(`${args.api}?${stringify(args.params)}`)
      fetchPromise.then((result)=>{
        cb(result)
      })
    }
    if(method === 'postData') {
      const fetchPromise = request(args.api, {
        method: 'POST',
        body: args.params,
      });
      fetchPromise.then((result) => {
        cb(result)
      })
    }
    return
  }

  if (isIOS()) {
    window.webkit.messageHandlers[method].postMessage(args)
  } else if (isAndroid()) {
    //console.log('调用安卓方法：' + method)
    if (args) {
      args = JSON.stringify(args)
    }
    window.android[method](args)
  }
}

let call = {}
let go = {}
const init = () => {
  window.nativeCallback = onNativeCallback
  for (let i = 0; i < METHOD_LIST.length; i++) {
    const method = METHOD_LIST[i]
    call[method] = (args, cb) => {
      //console.log('方法调用' + method)
      envokeNative(method, args, cb)
    }
  }
  for (let i = 0; i < PAGES.length; i++) {
    const page = PAGES[i]
    go[page] = (...rest) => {
      let args = {}, cb
      if (rest.length == 1) {
        if (typeof rest[0] === 'function') {
          cb = rest[0]
        } else {
          args = rest[0]
        }
      } else if (rest.length > 1) {
        args = rest[0]
        cb = rest[1]
      }
      envokeNative('go', {page, ...args}, cb)
    }
  }
}

const destroy = () => {
  // 注销所有方法
  for (let key in callbacks) {
    delete callbacks[key]
  }
  window.nativeCallback = null
}

export default {
  init,
  destroy,
  call,
  go
}